/***********************************************************************************
 *
 * Copyright (c) 2013 Louka Desroziers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 */

#import <UIKit/UIKit.h>

/** This UIImage category automatically generates a UIImage with -imageWithCapInsets: by using the name you provided to your graphic file.
 * This category is intended to avoid magic numbers in your code and allows UI designers to determine and quickly change the cap insets of any image.
 * You just need to add '{top,left,bottom,right}' before the file extension (and before @2x for retina images)
 * e.g.: for graphics named "navbar-background{0,4,0,4}.png" and "navbar-background{0,4,0,4}@2x.png", you will use :
 * [UIImage resizableImageNamed: @"navbar-background.png"]
 * or
 * [UIImage resizableImageWithContentsOfFile: [[NSBundle mainBundle] pathForResizableResource:@"navbar-background" ofType:@"png"]]
 * 
 */

@interface NSBundle (PXPAutomaticCapInsets)

- (NSString *)pathForResizableResource:(NSString *)name ofType:(NSString *)ext;
- (NSString *)pathForResizableResource:(NSString *)name ofType:(NSString *)ext inDirectory:(NSString *)subpath;

@end

@interface UIImage (PXPAutomaticCapInsets)

+ (UIImage *)resizableImageNamed:(NSString *)name;
+ (UIImage *)resizableImageNamed:(NSString *)name forMode:(UIImageResizingMode)resizingMode;

+ (UIImage *)resizableImageWithContentsOfFile:(NSString *)path;
+ (UIImage *)resizableImageWithContentsOfFile:(NSString *)path forMode:(UIImageResizingMode)resizingMode;

- (id)initWithResizableContentsOfFile:(NSString *)path;
- (id)initWithResizableContentsOfFile:(NSString *)path forMode:(UIImageResizingMode)resizingMode;

@end
